@@ -1,12 +1,18 @@
 import importlib.resources
+import sys
 
 
 def read_from_file(package: str, resource: str, encoding: str = "utf-8", errors: str = "strict") -> str:
     try:
-        with (importlib.resources.files(package) / resource).open("r", encoding=encoding, errors=errors) as f:
-            return f.read().strip()
+        if sys.version_info >= (3, 9):
+            with (importlib.resources.files(package) / resource).open("r", encoding=encoding, errors=errors) as f:
+                return f.read().strip()
+        else:
+            return importlib.resources.read_text(package, resource, encoding, errors).strip()
     except FileNotFoundError:
         return "0.0.0"
+    except AttributeError:
+        return "0.0.0"
 
 
 def read_version() -> str:
